# Terrayml

These are the steps in creating a new module:
    1. create module in modules folder
    2. create file template in file_templates folder
    3. create object_templates .json based on variables of module
    4. create mappings in mappings folder based on .json in object_templates
    5. create _generate_xxx function in generator.py